#!/usr/bin/env bash
clear

printf "\n%.0s" {1..2}  
echo -e "\e[35m
 ███▄    █  ██▓▒██   ██▒ ▒█████    ██████  ▄████▄   ▒█████   ███▄    █   █████▒██▓  ▄████ 
 ██ ▀█   █ ▓██▒▒▒ █ █ ▒░▒██▒  ██▒▒██    ▒ ▒██▀ ▀█  ▒██▒  ██▒ ██ ▀█   █ ▓██   ▒▓██▒ ██▒ ▀█▒
▓██  ▀█ ██▒▒██▒░░  █   ░▒██░  ██▒░ ▓██▄   ▒▓█    ▄ ▒██░  ██▒▓██  ▀█ ██▒▒████ ░▒██▒▒██░▄▄▄░
▓██▒  ▐▌██▒░██░ ░ █ █ ▒ ▒██   ██░  ▒   ██▒▒▓▓▄ ▄██▒▒██   ██░▓██▒  ▐▌██▒░▓█▒  ░░██░░▓█  ██▓
▒██░   ▓██░░██░▒██▒ ▒██▒░ ████▓▒░▒██████▒▒▒ ▓███▀ ░░ ████▓▒░▒██░   ▓██░░▒█░   ░██░░▒▓███▀▒
░ ▒░   ▒ ▒ ░▓  ▒▒ ░ ░▓ ░░ ▒░▒░▒░ ▒ ▒▓▒ ▒ ░░ ░▒ ▒  ░░ ▒░▒░▒░ ░ ▒░   ▒ ▒  ▒ ░   ░▓   ░▒   ▒ 
░ ░░   ░ ▒░ ▒ ░░░   ░▒ ░  ░ ▒ ▒░ ░ ░▒  ░ ░  ░  ▒     ░ ▒ ▒░ ░ ░░   ░ ▒░ ░      ▒ ░  ░   ░ 
   ░   ░ ░  ▒ ░ ░    ░  ░ ░ ░ ▒  ░  ░  ░  ░        ░ ░ ░ ▒     ░   ░ ░  ░ ░    ▒ ░░ ░   ░ 
         ░  ░   ░    ░      ░ ░        ░  ░ ░          ░ ░           ░         ░        ░ 
                                          ░                                               
\e[0m"
printf "\n%.0s" {1..1}

OK="$(tput setaf 2)[OK]$(tput sgr0)"
ERROR="$(tput setaf 1)[ERROR]$(tput sgr0)"
NOTE="$(tput setaf 3)[NOTE]$(tput sgr0)"
INFO="$(tput setaf 4)[INFO]$(tput sgr0)"
WARN="$(tput setaf 1)[WARN]$(tput sgr0)"
CAT="$(tput setaf 6)[ACTION]$(tput sgr0)"
MAGENTA="$(tput setaf 5)"
ORANGE="$(tput setaf 214)"
WARNING="$(tput setaf 1)"
YELLOW="$(tput setaf 3)"
GREEN="$(tput setaf 2)"
BLUE="$(tput setaf 4)"
SKY_BLUE="$(tput setaf 6)"
RESET="$(tput sgr0)"

set -e

if [ -n "$(grep -i nixos < /etc/os-release)" ]; then
  echo "${OK} verified distro to be nixos"
else
  echo "$ERROR this is not nixos or the distro info is not available!"
  exit 1
fi

if command -v git &> /dev/null; then
  echo "$OK git is installed, continuing with installation..."
  echo "-----"
else
  echo "$ERROR git is not installed, please install git and try again"
  exit 1
fi

echo "$NOTE ensure in home directory"
cd || exit

echo "-----"

backupname=$(date "+%Y-%m-%d-%H-%M-%S")
if [ -d "nixos-config" ]; then
  echo "$NOTE nixos-config exists, backing up to nixos-config-backups directory"
  if [ -d "nixos-config-backups" ]; then
    echo "moving current version of nixos-config to backups directory..."
    sudo mv "$HOME"/nixos-config nixos-config-backups/"$backupname"
    sleep 1
  else
    echo "$NOTE creating the backups directory and moving nixos-config into it..."
    mkdir -p nixos-config-backups
    sudo mv "$HOME"/nixos-config nixos-config-backups/"$backupname"
    sleep 1
  fi
else
  echo "$OK proceeding with installation"
fi

echo "-----"

echo "$NOTE cloning and entering nixos-config repository"
git clone --depth 1 https://g.r-io.lu/shynd/nixos-config.git ~/nixos-config
cd ~/nixos-config || exit

printf "\n%.0s" {1..2}

# check if we're running on a vm and enable option in default config.nix
if hostnamectl | grep -q 'Chassis: vm'; then
  echo "${NOTE} your system is running on a vm, enabling guest services..."
  echo "${WARN} remember to enable 3D acceleration!"
  sed -i '/vm\.guest-services\.enable = false;/s/vm\.guest-services\.enable = false;/ vm.guest-services.enable = true;/' hosts/default/config.nix
fi
printf "\n%.0s" {1..1}

# checking if system has a nvidia gpu and enable option in default config.nix
if command -v lspci > /dev/null 2>&1; then
  # lspci is available, proceed with checking for nvidia gpu
  if lspci -k | grep -A 2 -E "(VGA|3D)" | grep -iq nvidia; then
    echo "${NOTE} nvidia gpu detected, setting up for nvidia drivers..."
    sed -i '/drivers\.nvidia\.enable = false;/s/drivers\.nvidia\.enable = false;/ drivers.nvidia.enable = true;/' hosts/default/config.nix
  fi
fi

echo "-----"
printf "\n%.0s" {1..1}

# TODO